Installation
============

Create a virtual environment with Python 3.8 and install from git:

.. code-block:: bash

    pip install git+https://github.com/btcross26/genestboost.git

Alternatively, you can install directly from PyPi:

.. code-block:: bash

    $ pip install genestboost
